Add CFG support for the initializer of the condition variable of a WhileStmt.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@92105 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Analysis/CFG.cpp b/lib/Analysis/CFG.cpp
index cfdee49..fcdc95e 100644
--- a/lib/Analysis/CFG.cpp
+++ b/lib/Analysis/CFG.cpp
@@ -1188,8 +1188,21 @@
   // to this block.  NULL out Block to force lazy creation of another block.
   Block = NULL;
 
   // Return the condition block, which is the dominating block for the loop.
   Succ = EntryConditionBlock;
+  
+  // Finally, if the WhileStmt contains a condition variable, add both the 
+  // WhileStmt and the condition variable initialization to the CFG.
+  if (VarDecl *VD = W->getConditionVariable()) {
+    if (Expr *Init = VD->getInit()) {
+      autoCreateBlock();
+      AppendStmt(Block, W, AddStmtChoice::AlwaysAdd);
+      Succ = addStmt(Init);
+      return Succ;
+    }
+  }
+  
   return EntryConditionBlock;
 }
@@ -1188,8 +1188,21 @@
   Block = NULL;
 
-  // Return the condition block, which is the dominating block for the loop.
+  // Set Succ to be the condition block, which is the dominating block
+  // for the loop.
   Succ = EntryConditionBlock;